@@ -710,7 +710,33 @@ predictionFunction <- function(method, modelFit, newdata, param = NULL)
                            {
                              library(GAMens)
                              predict(modelFit, newdata)$class[,1]
-                           }
+                           },
+                           rocc =
+                           {
+                             library(rocc)
+                             tmp <- p.rocc(modelFit, t(as.matrix(newdata)))
+                             factor(ifelse(tmp == "1",  modelFit$obsLevels[1],  modelFit$obsLevels[2]),
+                                    levels =  modelFit$obsLevels)
+                           },
+                           foba =
+                           {
+                             library(foba)
+                             out <- predict(modelFit, newdata, k = modelFit$tuneValue$.k, type = "fit")$fit
+                             
+                             if(!is.null(param))
+                               {
+                                 tmp <- data.frame(
+                                                   matrix(NA, nrow = nrow(newdata), ncol = nrow(param)),
+                                                   stringsAsFactors = FALSE)
+                                 
+                                 for(j in seq(along = param$.k))
+                                   {
+                                     tmp[,j] <- predict(modelFit, newdata, k = param$.k[j], type = "fit")$fit
+                                   }
+                                 out <- cbind(out, tmp)
+                               }
+                             out
+                           },
                            )
   predictedValue
 }
